@@ -65,6 +65,9 @@ FAILEDOPERATION_GROUPEXISTS = 'FailedOperation.GroupExists'
 # 部署组查询失败。
 FAILEDOPERATION_GROUPQUERYFAILD = 'FailedOperation.GroupQueryFaild'
 
+# 机器实例删除失败。
+FAILEDOPERATION_INSTANCEDELETEFAILED = 'FailedOperation.InstanceDeleteFailed'
+
 # 查询机器实例部分失败。
 FAILEDOPERATION_INSTANCEQUERYFAILED = 'FailedOperation.InstanceQueryFailed'
 
@@ -140,12 +143,21 @@ FAILEDOPERATION_TKECLUSTERCREATEFAILED = 'FailedOperation.TkeClusterCreateFailed
 # TKE 集群查询失败。
 FAILEDOPERATION_TKECLUSTERQUERYFAILED = 'FailedOperation.TkeClusterQueryFailed'
 
-# resource服务错误。
-FAILEDOPERATION_TSFASRESOURCESERVERERROR = 'FailedOperation.TsfAsResourceServerError'
+# TSF应用性能管理CTSDB客户端调用失败。
+FAILEDOPERATION_TSFAPMCTSDBCLIENTREQUESTERROR = 'FailedOperation.TsfApmCtsdbClientRequestError'
+
+# ctsdb数据库请求失败。
+FAILEDOPERATION_TSFCMONITORCTSDBCLIENTREQUESTFAIL = 'FailedOperation.TsfCmonitorCtsdbClientRequestFail'
+
+# TSF监控统计等待超时, 请稍后重试。
+FAILEDOPERATION_TSFMONITORWAITEDTIMEOUT = 'FailedOperation.TsfMonitorWaitedTimeout'
 
 # TSF权限模块异常，请联系系统管理员。。
 FAILEDOPERATION_TSFPRIVILEGEERROR = 'FailedOperation.TsfPrivilegeError'
 
+# 模块未处理异常。
+FAILEDOPERATION_UNHANDLEDEXCEPTION = 'FailedOperation.UnhandledException'
+
 # 应用操作请求MASTER FEIGN失败。
 INTERNALERROR_APPLICATIONMASTERFEIGNERROR = 'InternalError.ApplicationMasterFeignError'
 
@@ -182,6 +194,9 @@ INTERNALERROR_CONTAINERGROUPKUBERNETEAPIINVOKEERROR = 'InternalError.Containergr
 # 连接TKE服务失败。
 INTERNALERROR_CONTAINERGROUPKUBERNETECONNECTERROR = 'InternalError.ContainergroupKuberneteConnectError'
 
+# Kubernetes deployment 未找到。
+INTERNALERROR_CONTAINERGROUPKUBERNETEDEPLOYMENTNOTFOUND = 'InternalError.ContainergroupKuberneteDeploymentNotfound'
+
 # 容器应用SQL错误。
 INTERNALERROR_CONTAINERGROUPSQLFAILED = 'InternalError.ContainergroupSqlFailed'
 
@@ -248,6 +263,15 @@ INTERNALERROR_TKEAPIFAILEDOPERATION = 'InternalError.TkeApiFailedOperation'
 # TSF应用性能管理ES客户端响应状态异常。
 INTERNALERROR_TSFAPMESRESPONSESTATUSEXCEPTION = 'InternalError.TsfApmEsResponseStatusException'
 
+# TSF应用性能管理内部异常, 请稍后重试。
+INTERNALERROR_TSFAPMINTERNALERROR = 'InternalError.TsfApmInternalError'
+
+# TSF监控统计时间日期解析失败。
+INTERNALERROR_TSFMONITORDATEPARSEFAILED = 'InternalError.TsfMonitorDateParseFailed'
+
+# TSF监控统计内部异常, 请稍后重试。
+INTERNALERROR_TSFMONITORINTERNALERROR = 'InternalError.TsfMonitorInternalError'
+
 # [%s]模块未处理异常。。
 INTERNALERROR_UNHANDLEDEXCEPTION = 'InternalError.UnhandledException'
 
@@ -260,6 +284,9 @@ INVALIDPARAMETER_BADREQUEST = 'InvalidParameter.BadRequest'
 # TSF MASTER 实例状态异常。
 INVALIDPARAMETER_CVMCAEMASTERUNKNOWNINSTANCESTATUS = 'InvalidParameter.CvmCaeMasterUnknownInstanceStatus'
 
+# 未找到 TCR 实例或命名空间。
+INVALIDPARAMETER_IMAGEREPOTCRNAMESPACENOTFOUND = 'InvalidParameter.ImagerepoTcrNamespaceNotFound'
+
 # 参数错误。
 INVALIDPARAMETER_KUBERNETESPARAMERROR = 'InvalidParameter.KubernetesParamError'
 
@@ -341,18 +368,24 @@ INVALIDPARAMETER_TSFAPMBUSILOGCFGAPPRELATIONPARAMERROR = 'InvalidParameter.TsfAp
 # TSF应用性能管理业务日志搜索请求参数错误。
 INVALIDPARAMETER_TSFAPMBUSILOGSEARCHREQUESTPARAMERROR = 'InvalidParameter.TsfApmBusiLogSearchRequestParamError'
 
+# TSF应用性能管理运行状态统计查询请求参数错误。
+INVALIDPARAMETER_TSFAPMSTATSSEARCHREQUESTPARAMERROR = 'InvalidParameter.TsfApmStatsSearchRequestParamError'
+
 # TSF应用性能管理标准输出日志搜索请求参数错误。
 INVALIDPARAMETER_TSFAPMSTDOUTSEARCHREQUESTPARAMERROR = 'InvalidParameter.TsfApmStdoutSearchRequestParamError'
 
+# TSF应用性能管理调用链搜索请求参数错误。
+INVALIDPARAMETER_TSFAPMTRACESEARCHREQUESTPARAMERROR = 'InvalidParameter.TsfApmTraceSearchRequestParamError'
+
+# TSF监控统计请求参数[%s]非法。
+INVALIDPARAMETER_TSFMONITORREQUESTPARAMILLEGAL = 'InvalidParameter.TsfMonitorRequestParamIllegal'
+
 # 仓库批量删除包数量超过单次允许上限。
 INVALIDPARAMETER_UPPERDELETELIMIT = 'InvalidParameter.UpperDeleteLimit'
 
 # 参数取值错误。
 INVALIDPARAMETERVALUE = 'InvalidParameterValue'
 
-# 所属应用ID不能为空。
-INVALIDPARAMETERVALUE_APPLICATIONIDNULL = 'InvalidParameterValue.ApplicationIdNull'
-
 # 无效的微服务类型。
 INVALIDPARAMETERVALUE_APPLICATIONMICROTYPEINVALID = 'InvalidParameterValue.ApplicationMicroTypeInvalid'
 
@@ -434,6 +467,9 @@ INVALIDPARAMETERVALUE_CONTAINERGROUPAPPLICATIONIDNULL = 'InvalidParameterValue.C
 # 集群 CPU 资源不足。
 INVALIDPARAMETERVALUE_CONTAINERGROUPCPULIMITOVER = 'InvalidParameterValue.ContainergroupCpulimitOver'
 
+# 容器 Env 的 Value 和 ValueFrom 至少要有一个。
+INVALIDPARAMETERVALUE_CONTAINERGROUPENVVALUENOTSET = 'InvalidParameterValue.ContainergroupEnvValueNotSet'
+
 # 部署组ID不能为空。
 INVALIDPARAMETERVALUE_CONTAINERGROUPGROUPIDNULL = 'InvalidParameterValue.ContainergroupGroupidNull'
 
@@ -452,6 +488,9 @@ INVALIDPARAMETERVALUE_CONTAINERGROUPINVALIDCPUINFO = 'InvalidParameterValue.Cont
 # 内存 limit 和 request 不能同时为空。
 INVALIDPARAMETERVALUE_CONTAINERGROUPINVALIDMEMINFO = 'InvalidParameterValue.ContainergroupInvalidMemInfo'
 
+# limit最大数量，默认 20, 最大值 50。
+INVALIDPARAMETERVALUE_CONTAINERGROUPLIMITVALUEINVALID = 'InvalidParameterValue.ContainergroupLimitValueInvalid'
+
 # 集群内存资源不足。
 INVALIDPARAMETERVALUE_CONTAINERGROUPMEMLIMITOVER = 'InvalidParameterValue.ContainergroupMemlimitOver'
 
@@ -485,6 +524,9 @@ INVALIDPARAMETERVALUE_CONTAINERGROUPTARGETPORTNULL = 'InvalidParameterValue.Cont
 # 更新间隔不能为空或者数值非法。
 INVALIDPARAMETERVALUE_CONTAINERGROUPUPDATEIVLINVALID = 'InvalidParameterValue.ContainergroupUpdateivlInvalid'
 
+# updateType参数不合法，值必须为0、1。
+INVALIDPARAMETERVALUE_CONTAINERGROUPUPDATETYPEINVALID = 'InvalidParameterValue.ContainergroupUpdatetypeInvalid'
+
 # 找不到业务容器。
 INVALIDPARAMETERVALUE_CONTAINERGROUPYAMLUSERCONTAINERNOTFOUND = 'InvalidParameterValue.ContainergroupYamlUserContainerNotFound'
 
@@ -518,6 +560,9 @@ INVALIDPARAMETERVALUE_FILECONFIGFILEPATHINVALID = 'InvalidParameterValue.FileCon
 # 文件配置项名称不合规。
 INVALIDPARAMETERVALUE_FILECONFIGNAMEINVALID = 'InvalidParameterValue.FileConfigNameInvalid'
 
+# 无法获取文件配置项或无权限访问。
+INVALIDPARAMETERVALUE_FILECONFIGNOTEXISTSORPERMISSIONDENIED = 'InvalidParameterValue.FileConfigNotExistsOrPermissionDenied'
+
 # 同一部署组禁止配置文件重复(文件路径+文件名)。
 INVALIDPARAMETERVALUE_FILECONFIGPATHEXISTS = 'InvalidParameterValue.FileConfigPathExists'
 
@@ -539,6 +584,12 @@ INVALIDPARAMETERVALUE_GROUPBATCHPARAMETERINVALID = 'InvalidParameterValue.GroupB
 # 部署组的集群未绑定该命名空间。
 INVALIDPARAMETERVALUE_GROUPCLUSTERNAMESPACENOTBOUND = 'InvalidParameterValue.GroupClusterNamespaceNotBound'
 
+# 创建分组， 集群类型不匹配。
+INVALIDPARAMETERVALUE_GROUPCLUSTERTYPEMISMATCH = 'InvalidParameterValue.GroupClusterTypeMismatch'
+
+# 删除分组，集群类型不匹配。
+INVALIDPARAMETERVALUE_GROUPDELETECLUSTERTYPEMISMATCH = 'InvalidParameterValue.GroupDeleteClusterTypeMismatch'
+
 # 部署组ID不能为空。
 INVALIDPARAMETERVALUE_GROUPIDNULL = 'InvalidParameterValue.GroupIdNull'
 
@@ -548,9 +599,6 @@ INVALIDPARAMETERVALUE_GROUPNAMEEXIST = 'InvalidParameterValue.GroupNameExist'
 # 部署组名不能大于50个字符。
 INVALIDPARAMETERVALUE_GROUPNAMELENGTH = 'InvalidParameterValue.GroupNameLength'
 
-# 部署组名不能为空。
-INVALIDPARAMETERVALUE_GROUPNAMENULL = 'InvalidParameterValue.GroupNameNull'
-
 # 部署组名称格式不正确,只能包含小写字母、数字及分隔符("-"),且必须以小写字母开头，数字或小写字母结尾。
 INVALIDPARAMETERVALUE_GROUPNAMEREGXMISMATCH = 'InvalidParameterValue.GroupNameRegxMismatch'
 
@@ -560,9 +608,6 @@ INVALIDPARAMETERVALUE_GROUPNOTEXISTS = 'InvalidParameterValue.GroupNotExists'
 # 分组无效的分业参数。
 INVALIDPARAMETERVALUE_GROUPPAGELIMITINVALID = 'InvalidParameterValue.GroupPageLimitInvalid'
 
-# 程序包不能为空。
-INVALIDPARAMETERVALUE_GROUPPKGNULL = 'InvalidParameterValue.GroupPkgNull'
-
 # 无效的部署组状态过滤字段。
 INVALIDPARAMETERVALUE_GROUPSTATUSINVALID = 'InvalidParameterValue.GroupStatusInvalid'
 
@@ -581,6 +626,9 @@ INVALIDPARAMETERVALUE_IMAGEREPOTAGNAMENULL = 'InvalidParameterValue.ImagerepoTag
 # 重装系统，无效的镜像id。
 INVALIDPARAMETERVALUE_INSTANCEINVALIDIMAGE = 'InvalidParameterValue.InstanceInvalidImage'
 
+# 参数 %s 取值错误。
+INVALIDPARAMETERVALUE_INVALIDPARAMETER = 'InvalidParameterValue.InvalidParameter'
+
 # 参数格式异常。
 INVALIDPARAMETERVALUE_INVALIDPARAMETERFORMAT = 'InvalidParameterValue.InvalidParameterFormat'
 
@@ -770,9 +818,6 @@ RESOURCEINUSE_OBJECTEXIST = 'ResourceInUse.ObjectExist'
 # 限流规则已存在，请检查规则名和规则配置。
 RESOURCEINUSE_RATELIMITRULEEXISTERROR = 'ResourceInUse.RatelimitRuleExistError'
 
-# 实例数已达上限。
-RESOURCEINSUFFICIENT_INSTANCEEXCESSLIMIT = 'ResourceInsufficient.InstanceExcessLimit'
-
 # 仓库空间达到上限。
 RESOURCEINSUFFICIENT_PACKAGESPACEFULL = 'ResourceInsufficient.PackageSpaceFull'
 
